from django.test import TestCase
from django.utils.translation import activate, get_language
from django.template import Template, RequestContext, TemplateSyntaxError
from context_processors import bidi

class ContextTest(TestCase):
    """Test for correct context processor"""

    def setUp(self):
        # keep orig language
        self.orig_language = get_language()

    def tearDown(self):
        # restore orig language
        activate(self.orig_language)

    def test_ltr(self):
        """Test for left-to-right languages"""
        activate('en-us')

        ctx = bidi({})
        self.failUnlessEqual(ctx, {
            'LANGUAGE_END': 'right',
            'LANGUAGE_START': 'left',
            'LANGUAGE_DIRECTION': 'ltr',
            'LANGUAGE_MARKER': '&lrm;',
        })

    def test_rtl(self):
        """Test for right-to-left languages"""
        activate('he')

        ctx = bidi({})
        self.failUnlessEqual(ctx, {
            'LANGUAGE_END': 'left',
            'LANGUAGE_START': 'right',
            'LANGUAGE_DIRECTION': 'rtl',
            'LANGUAGE_MARKER': '&rlm;',
        })

    def render(self, template, **kwargs):
        """Return the rendering of a given template"""
        return Template(template).render(RequestContext(kwargs)).strip()

    def test_ltr_template(self):
        """Test for ltr variables in template"""
        activate('en-us')
        response = self.render('{{LANGUAGE_START}} {{LANGUAGE_END}} {{LANGUAGE_DIRECTION}} ' +\
            '{{LANGUAGE_MARKER}}'
        )

        self.failUnlessEqual(response, 'left right ltr &lrm;')

    def test_rtl_template(self):
        """Test for rtl variables in template"""
        activate('he')
        response = self.render('{{LANGUAGE_START}} {{LANGUAGE_END}} {{LANGUAGE_DIRECTION}} ' +\
            '{{LANGUAGE_MARKER}}'
        )

        self.failUnlessEqual(response, u'right left rtl &rlm;')



"""Context processors for BiDi"""

def bidi(request):
    """Adds to the context BiDi related variables

    LANGUAGE_DIRECTION -- Direction of current language ('ltr' or 'rtl')
    LANGUAGE_START -- Start of language layout ('right' for rtl, 'left'
                      for 'ltr')
    LANGUAGE_END -- End of language layout ('left' for rtl, 'right'
                      for 'ltr')
    LANGUAGE_MARKER -- Language marker entity ('&rlm;' for rtl, '&lrm'
                       for ltr)

    """
    from django.utils import translation
    from django.utils.safestring import mark_safe

    if translation.get_language_bidi():
        extra_context = {
            'LANGUAGE_DIRECTION':'rtl',
            'LANGUAGE_START':'right',
            'LANGUAGE_END':'left',
            'LANGUAGE_MARKER': mark_safe('&rlm;'),
        }
    else:
        extra_context = {
            'LANGUAGE_DIRECTION':'ltr',
            'LANGUAGE_START':'left',
            'LANGUAGE_END':'right',
            'LANGUAGE_MARKER': mark_safe('&lrm;'),
        }

    return extra_context



import os
from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "django-bidi-utils",
    version = "0.1",
    url = 'http://github.com/mksoft/django-bidi-utils',
    license = 'MIT',
    description = "context processors and helpers for BIDI in django templates",
    long_description = read('README'),

    author = 'Meir Kriheli',
    author_email = 'meir@mksoft.co.il',

    packages = find_packages('src'),
    package_dir = {'': 'src'},

    install_requires = ['setuptools'],

    classifiers = [
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ]
)
